@@ -1,18 +1,19 @@
 package HTML::Widgets::NavMenu::HeaderRole;
 
 use strict;
+use warnings;
 
 use base 'HTML::Widgets::NavMenu';
 
 require HTML::Widgets::NavMenu::Iterator::NavMenu::HeaderRole;
 
-sub get_nav_menu_traverser
+sub _get_nav_menu_traverser
 {
     my $self = shift;
 
     return
         HTML::Widgets::NavMenu::Iterator::NavMenu::HeaderRole->new(
-            $self->get_nav_menu_traverser_args()
+            $self->_get_nav_menu_traverser_args()
         );
 }
 
@@ -22,7 +23,7 @@ __END__
 
 =head1 NAME
 
-HTML::Widgets::NavMenu::HeaderRole - A Specialized HTML::Widgets::NavMenu 
+HTML::Widgets::NavMenu::HeaderRole - A Specialized HTML::Widgets::NavMenu
 sub-class
 
 =head1 SYNOPOSIS
@@ -45,7 +46,7 @@ C<E<lt>h2E<gt>> header. The HTML will look something like this:
     </h2>
     <ul>
 
-An example of this use can be found in the Perl Beginners Site 
+An example of this use can be found in the Perl Beginners Site
 ( L<http://perl-begin.berlios.de/> ).
 
 =head1 SEE ALSO
@@ -54,8 +55,7 @@ L<HTML::Widgets::NavMenu> for the complete documentation of the super-class.
 
 =head1 AUTHORS
 
-Shlomi Fish E<lt>shlomif@iglu.org.ilE<gt> 
-(L<http://search.cpan.org/~shlomif/>).
+Shlomi Fish, L<http://www.shlomifish.org> .
 
-=cut 
+=cut
 
